From: Josh Poimboeuf <jpoimboe@kernel.org>
To: Brian Johannesmeyer <bjohannesmeyer@gmail.com>
Cc: linux-kernel@vger.kernel.org
Subject: Re: [PATCH 0/7] Improve performance of 'faddr2line'
Date: Tue, 12 Mar 2024 16:06:16 -0700 [thread overview]
Message-ID: <20240312230616.u7rvo2iowdumlm2v@treble> (raw)
In-Reply-To: <20240311204019.1183634-1-bjohannesmeyer@gmail.com>
On Mon, Mar 11, 2024 at 09:40:12PM +0100, Brian Johannesmeyer wrote:
> Hello,
>
> I was looking at the performance of faddr2line and noticed that it spends
> most of its time performing two tasks:
> - (1) Making redundant calls to readelf and addr2line for each address
> (e.g., it makes 7 readelf calls and 2 addr2line calls when converting 1
> address, and it makes 252 readelf calls and 51 addr2line calls when
> converting 50 addresses); and
> - (2) Calculating a symbol’s size by unnecessarily looping through every
> symbol in a particular section.
>
> This patch series consists of the following parts:
> - Patches 1-2 reduce the total number of readelf calls to one,
> - Patches 3-4 make minor changes in preparation for the following patches,
> - Patches 5-6 reduce the total number of addr2line calls to one, and
> - Patch 7 modifies the symbol size calculation to only check two symbols.
>
> I evaluated the performance of the patch series by running faddr2line with
> a standard kernel image (X86_64 defconfig with CONFIG_DEBUG_INFO enabled).
> When converting only 1 address, the patch series gives a negligible
> speedup. When converting 50 addresses, however, it gives a 15x speedup.
This looks really nice.
If testing runs ok, I'll go ahead and queue it up.
Thanks!
--
Josh
prev parent reply other threads:[~2024-03-12 23:06 UTC|newest]
Thread overview: 11+ messages / expand[flat|nested] mbox.gz Atom feed top
2024-03-11 20:40 Brian Johannesmeyer
2024-03-11 20:40 ` [PATCH 1/7] scripts/faddr2line: Reduce number of readelf calls to three Brian Johannesmeyer
2024-03-11 20:40 ` [PATCH 2/7] scripts/faddr2line: Combine three readelf calls into one Brian Johannesmeyer
2024-03-11 20:40 ` [PATCH 3/7] scripts/faddr2line: Check vmlinux only once Brian Johannesmeyer
2024-03-11 20:40 ` [PATCH 4/7] scripts/faddr2line: Pass --addresses argument to addr2line Brian Johannesmeyer
2024-03-11 20:40 ` [PATCH 5/7] scripts/faddr2line: Invoke addr2line as a single long-running process Brian Johannesmeyer
2024-03-11 20:40 ` [PATCH 6/7] scripts/faddr2line: Remove call to addr2line from find_dir_prefix() Brian Johannesmeyer
2024-03-11 20:40 ` [PATCH 7/7] scripts/faddr2line: Check only two symbols when calculating symbol size Brian Johannesmeyer
2024-04-11 19:28 ` Brian Johannesmeyer
2024-04-12 20:27 ` Josh Poimboeuf
2024-03-12 23:06 ` Josh Poimboeuf [this message]
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20240312230616.u7rvo2iowdumlm2v@treble \
--to=jpoimboe@kernel.org \
--cc=bjohannesmeyer@gmail.com \
--cc=linux-kernel@vger.kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®